pub enum GuidanceReason {
SlowMovingASIN,
NoApplicableGuidance,
}Expand description
GuidanceReason : A reason for the current inbound guidance for an item. A reason for the current inbound guidance for an item.
Variants
SlowMovingASIN
NoApplicableGuidance